.. _models:

Models
******

.. currentmodule:: torchkge.models


Translational Models
====================

.. automodule:: torchkge.models.TranslationModels

TransE
------
.. autoclass:: torchkge.models.TranslationModels.TransEModel
   :members:

TransH
------
.. autoclass:: torchkge.models.TranslationModels.TransHModel
   :members:

TransR
------
.. autoclass:: torchkge.models.TranslationModels.TransRModel
   :members:

TransD
------
.. autoclass:: torchkge.models.TranslationModels.TransDModel
   :members:

Bilinear Models
===============

.. automodule:: torchkge.models.BilinearModels

RESCAL
------
.. autoclass:: torchkge.models.BilinearModels.RESCALModel
   :members:

DistMult
--------
.. autoclass:: torchkge.models.BilinearModels.DistMultModel
   :members:

HolE
----
.. autoclass:: torchkge.models.BilinearModels.HolEModel
   :members:

ComplEx
-------
.. autoclass:: torchkge.models.BilinearModels.ComplExModel
   :members:

ANALOGY
-------
.. autoclass:: torchkge.models.BilinearModels.AnalogyModel
   :members:
